@@ -1,22 +1,35 @@
 /*
-    This file is part of the kholidays library.
+  This file is part of the kholidays library.
 
-    SPDX-FileCopyrightText: 2014 John Layt <john@layt.net>
+  Copyright 2014 John Layt <john@layt.net>
 
-    SPDX-License-Identifier: LGPL-2.0-or-later
+  This library is free software; you can redistribute it and/or
+  modify it under the terms of the GNU Library General Public
+  License as published by the Free Software Foundation; either
+  version 2 of the License, or (at your option) any later version.
+
+  This library is distributed in the hope that it will be useful,
+  but WITHOUT ANY WARRANTY; without even the implied warranty of
+  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+  GNU Library General Public License for more details.
+
+  You should have received a copy of the GNU Library General Public License
+  along with this library; see the file COPYING.LIB.  If not, write to the
+  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+  Boston, MA 02110-1301, USA.
 */
 
 #include "qcalendarsystem_p.h"
 
-#include <kholidays_debug.h>
+#include <QtCore/QDate>
+#include <QtCore/QSharedData>
 
-#include <QDate>
-#include <QSharedData>
+#include "qdebug.h"
 
 class QCalendarSystemPrivate : public QSharedData
 {
 public:
-    explicit QCalendarSystemPrivate(QCalendarSystem::CalendarSystem calendar);
+    QCalendarSystemPrivate(QCalendarSystem::CalendarSystem calendar);
 
     QCalendarSystem::CalendarSystem calendarSystem() const;
     qint64 epoch() const;
@@ -47,11 +60,11 @@ public:
     QCalendarSystem::CalendarSystem m_calendarSystem;
 };
 
-static const char julianMonths[] = {0, 31, 28, 31, 30, 31, 30, 31, 31, 30, 31, 30, 31};
+static const char julianMonths[] = { 0, 31, 28, 31, 30, 31, 30, 31, 31, 30, 31, 30, 31 };
 
 QCalendarSystemPrivate::QCalendarSystemPrivate(QCalendarSystem::CalendarSystem calendar)
-    : QSharedData()
-    , m_calendarSystem(calendar)
+    : QSharedData(),
+      m_calendarSystem(calendar)
 {
 }
 
@@ -68,27 +81,27 @@ qint64 QCalendarSystemPrivate::epoch() const
 {
     switch (calendarSystem()) {
     case QCalendarSystem::GregorianCalendar:
-        return 1721426; //  0001-01-01 Gregorian
+        return 1721426;  //  0001-01-01 Gregorian
     case QCalendarSystem::CopticCalendar:
-        return 1825030; //  0001-01-01 ==  0284-08-29 Gregorian
+        return 1825030;  //  0001-01-01 ==  0284-08-29 Gregorian
     case QCalendarSystem::EthiopicCalendar:
-        return 1724221; //  0001-01-01 ==  0008-08-29 Gregorian
+        return 1724221;  //  0001-01-01 ==  0008-08-29 Gregorian
     case QCalendarSystem::EthiopicAmeteAlemCalendar:
-        return -284655; //  0001-01-01 == -5492-08-29 Gregorian
+        return -284655;  //  0001-01-01 == -5492-08-29 Gregorian
     case QCalendarSystem::IndianNationalCalendar:
-        return 1749994; //  0000-01-01 == 0078-03-22 Gregorian
+        return 1749994;  //  0000-01-01 == 0078-03-22 Gregorian
     case QCalendarSystem::IslamicCivilCalendar:
-        return 1948440; //  0001-01-01 == 0622-07-19 Gregorian
+        return 1948440;  //  0001-01-01 == 0622-07-19 Gregorian
     case QCalendarSystem::ISO8601Calendar:
-        return 1721060; //  0000-01-01 Gregorian
+        return 1721060;  //  0000-01-01 Gregorian
     case QCalendarSystem::JapaneseCalendar:
-        return 1721426; //  0001-01-01 Gregorian
+        return 1721426;  //  0001-01-01 Gregorian
     case QCalendarSystem::JulianCalendar:
-        return 1721424; //  0001-01-01 ==  Gregorian
+        return 1721424;  //  0001-01-01 ==  Gregorian
     case QCalendarSystem::ROCCalendar:
-        return 2419403; //  0001-01-01 ==  1912-01-01 Gregorian
+        return 2419403;  //  0001-01-01 ==  1912-01-01 Gregorian
     case QCalendarSystem::ThaiCalendar:
-        return 1522734; //  0000-01-01 == -0544-01-01 Gregorian
+        return 1522734;  //  0000-01-01 == -0544-01-01 Gregorian
     default:
         return 0;
     }
@@ -98,27 +111,27 @@ qint64 QCalendarSystemPrivate::earliestValidDate() const
 {
     switch (calendarSystem()) {
     case QCalendarSystem::GregorianCalendar:
-        return -31738; // -4800-01-01 Gregorian
+        return -31738;   // -4800-01-01 Gregorian
     case QCalendarSystem::CopticCalendar:
-        return 1825030; //  0001-01-01 == 0284-08-29 Gregorian
+        return 1825030;  //  0001-01-01 == 0284-08-29 Gregorian
     case QCalendarSystem::EthiopicCalendar:
-        return 1724221; //  0001-01-01 == 0008-08-29 Gregorian
+        return 1724221;  //  0001-01-01 == 0008-08-29 Gregorian
     case QCalendarSystem::EthiopicAmeteAlemCalendar:
-        return -284655; //  0001-01-01 == -5492-08-29 Gregorian
+        return -284655;  //  0001-01-01 == -5492-08-29 Gregorian
     case QCalendarSystem::IndianNationalCalendar:
-        return 1749994; //  0000-01-01 == 0078-03-22 Gregorian
+        return 1749994;  //  0000-01-01 == 0078-03-22 Gregorian
     case QCalendarSystem::IslamicCivilCalendar:
-        return 1948440; //  0001-01-01 == 0622-07-19 Gregorian
+        return 1948440;  //  0001-01-01 == 0622-07-19 Gregorian
     case QCalendarSystem::ISO8601Calendar:
-        return 1721060; //  0000-01-01 Gregorian
+        return 1721060;  //  0000-01-01 Gregorian
     case QCalendarSystem::JapaneseCalendar:
-        return -31738; // -4800-01-01 Gregorian
+        return -31738;   // -4800-01-01 Gregorian
     case QCalendarSystem::JulianCalendar:
-        return -31776; // -4800-01-01 Julian
+        return -31776;   // -4800-01-01 Julian
     case QCalendarSystem::ROCCalendar:
-        return 2419403; //  0001-01-01 == 1912-01-01 Gregorian
+        return 2419403;  //  0001-01-01 == 1912-01-01 Gregorian
     case QCalendarSystem::ThaiCalendar:
-        return 1522734; //  0000-01-01 == -0544-01-01 Gregorian
+        return 1522734;  //  0000-01-01 == -0544-01-01 Gregorian
     default:
         return 0;
     }
@@ -144,27 +157,27 @@ qint64 QCalendarSystemPrivate::latestValidDate() const
 {
     switch (calendarSystem()) {
     case QCalendarSystem::GregorianCalendar:
-        return 5373484; //  9999-12-31 Gregorian
+        return 5373484;  //  9999-12-31 Gregorian
     case QCalendarSystem::CopticCalendar:
-        return 5477164; //  9999-13-05 == 10283-11-12 Gregorian
+        return 5477164;  //  9999-13-05 == 10283-11-12 Gregorian
     case QCalendarSystem::EthiopicCalendar:
-        return 5376721; //  9999-13-05 == 10008-11-10 Gregorian
+        return 5376721;  //  9999-13-05 == 10008-11-10 Gregorian
     case QCalendarSystem::EthiopicAmeteAlemCalendar:
-        return 3367114; //  9999-13-05 ==  4506-09-29 Gregorian
+        return 3367114;  //  9999-13-05 ==  4506-09-29 Gregorian
     case QCalendarSystem::IndianNationalCalendar:
-        return 5402054; //  9999-12-30 == 10078-03-21 Gregorian
+        return 5402054;  //  9999-12-30 == 10078-03-21 Gregorian
     case QCalendarSystem::IslamicCivilCalendar:
-        return 5491751; //  9999-12-29 == 10323-10-21 Gregorian
+        return 5491751;  //  9999-12-29 == 10323-10-21 Gregorian
     case QCalendarSystem::ISO8601Calendar:
-        return 5373484; //  9999-12-31 Gregorian
+        return 5373484;  //  9999-12-31 Gregorian
     case QCalendarSystem::JapaneseCalendar:
-        return 5373484; //  9999-12-31 Gregorian
+        return 5373484;  //  9999-12-31 Gregorian
     case QCalendarSystem::JulianCalendar:
-        return 5373557; //  9999-12-31 == 10000-03-13 Gregorian
+        return 5373557;  //  9999-12-31 == 10000-03-13 Gregorian
     case QCalendarSystem::ROCCalendar:
-        return 6071462; //  9999-12-31 == 11910-12-31 Gregorian
+        return 6071462;  //  9999-12-31 == 11910-12-31 Gregorian
     case QCalendarSystem::ThaiCalendar:
-        return 5175158; //  9999-12-31 ==  9456-12-31 Gregorian
+        return 5175158;  //  9999-12-31 ==  9456-12-31 Gregorian
     default:
         return 0;
     }
@@ -182,9 +195,9 @@ int QCalendarSystemPrivate::yearOffset() const
 {
     switch (calendarSystem()) {
     case QCalendarSystem::ROCCalendar:
-        return 1911; // 0001-01-01 == 1912-01-01 Gregorian
+        return 1911;  // 0001-01-01 == 1912-01-01 Gregorian
     case QCalendarSystem::ThaiCalendar:
-        return -543; // 0000-01-01 == -544-01-01 Gregorian
+        return -543;  // 0000-01-01 == -544-01-01 Gregorian
     default:
         return 0;
     }
@@ -204,8 +217,7 @@ int QCalendarSystemPrivate::maxMonthsInYear() const
 
 int QCalendarSystemPrivate::monthsInYear(int year) const
 {
-    // year = year + yearOffset();
-    Q_UNUSED(year);
+    year = year + yearOffset();
 
     switch (calendarSystem()) {
     case QCalendarSystem::CopticCalendar:
@@ -332,7 +344,6 @@ int QCalendarSystemPrivate::quarter(int month) const
         if (month == 13) { // Consider the short epagomenal month as part of the 4th quarter
             return 4;
         }
-        Q_FALLTHROUGH();
     default:
         return (((month - 1) / 3) + 1);
     }
@@ -375,18 +386,17 @@ bool QCalendarSystemPrivate::isLeapYear(int year) const
 
 void QCalendarSystemPrivate::julianDayToDate(qint64 jd, int *year, int *month, int *day) const
 {
-    int yy = 0;
-    int mm = 0;
-    int dd = 0;
+    int yy, mm, dd;
 
     switch (calendarSystem()) {
+
     case QCalendarSystem::GregorianCalendar:
     case QCalendarSystem::ISO8601Calendar:
     case QCalendarSystem::JapaneseCalendar:
     case QCalendarSystem::ROCCalendar:
     case QCalendarSystem::ThaiCalendar: {
         // Formula from The Calendar FAQ by Claus Tondering
-        // https://www.tondering.dk/claus/calendar.html
+        // http://www.tondering.dk/claus/cal/node3.html#SECTION003161000000000000000
         qint64 a = jd + 32044;
         qint64 b = ((4 * a) + 3) / 146097;
         qint64 c = a - ((146097 * b) / 4);
@@ -405,11 +415,10 @@ void QCalendarSystemPrivate::julianDayToDate(qint64 jd, int *year, int *month, i
         // Formula derived from first principles by John Layt
         qint64 s = jd - (epoch() - 365);
         qint64 l = s / 1461;
-        yy = (l * 4) + qMin(static_cast<qint64>(3), (s % 1461) / 365);
+        yy = (l * 4) + qMin((qint64)3, (s % 1461) / 365);
         qint64 diy = s - (yy * 365) + (yy / 4);
         mm = (diy / 30) + 1;
         dd = (diy % 30) + 1;
-        break;
     }
 
     case QCalendarSystem::IndianNationalCalendar: {
@@ -426,7 +435,6 @@ void QCalendarSystemPrivate::julianDayToDate(qint64 jd, int *year, int *month, i
         l = j / 11;
         mm = j + 2 - 12 * l;
         yy = 100 * (n - 49) + l + i - 78;
-        break;
     }
 
     case QCalendarSystem::IslamicCivilCalendar: {
@@ -441,12 +449,11 @@ void QCalendarSystemPrivate::julianDayToDate(qint64 jd, int *year, int *month, i
         yy = (30 * n) + j - 30;
         mm = (24 * l) / 709;
         dd = l - ((709 * mm) / 24);
-        break;
     }
 
     case QCalendarSystem::JulianCalendar: {
         // Formula from The Calendar FAQ by Claus Tondering
-        // https://www.tondering.dk/claus/calendar.html
+        // http://www.tondering.dk/claus/cal/node3.html#SECTION003161000000000000000
         qint64 b = 0;
         qint64 c = jd + 32082;
         qint64 d = ((4 * c) + 3) / 1461;
@@ -490,22 +497,24 @@ qint64 QCalendarSystemPrivate::julianDayFromDate(int year, int month, int day) c
     }
 
     switch (calendarSystem()) {
+
     case QCalendarSystem::GregorianCalendar:
     case QCalendarSystem::ISO8601Calendar:
     case QCalendarSystem::JapaneseCalendar:
     case QCalendarSystem::ROCCalendar:
     case QCalendarSystem::ThaiCalendar: {
         // Formula from The Calendar FAQ by Claus Tondering
-        // https://www.tondering.dk/claus/calendar.html
+        // http://www.tondering.dk/claus/cal/node3.html#SECTION003161000000000000000
         int a = (14 - month) / 12;
         year = year + 4800 - a;
         int m = month + (12 * a) - 3;
-        jd = day + (((153 * m) + 2) / 5) //
-            + (365 * year) //
-            + (year / 4) //
-            - (year / 100) //
-            + (year / 400) //
-            - 32045;
+        jd = day
+             + (((153 * m) + 2) / 5)
+             + (365 * year)
+             + (year / 4)
+             - (year / 100)
+             + (year / 400)
+             - 32045;
         break;
     }
 
@@ -513,53 +522,51 @@ qint64 QCalendarSystemPrivate::julianDayFromDate(int year, int month, int day) c
     case QCalendarSystem::EthiopicCalendar:
     case QCalendarSystem::EthiopicAmeteAlemCalendar: {
         // Formula derived from first principles by John Layt
-        jd = epoch() - 1 //
-            + ((year - 1) * 365) //
-            + (year / 4) //
-            + ((month - 1) * 30) //
-            + day;
-        break;
+        jd = epoch() - 1
+             + ((year - 1) * 365)
+             + (year / 4)
+             + ((month - 1) * 30)
+             + day;
     }
 
     case QCalendarSystem::IndianNationalCalendar: {
         // Formula from the "Explanatory Supplement to the Astronomical Almanac"
         // Revised Edition 2006 section 12.94 pp 605-606, US Naval Observatory
         // Originally from the "Report of the Calendar Reform Committee" 1955, Indian Government
-        jd = 365 * year + (year + 78 - 1 / month) / 4 //
-            + 31 * month //
-            - (month + 9) / 11 //
-            - (month / 7) * (month - 7) //
-            - (3 * ((year + 78 - 1 / month) / 100 + 1)) / 4 //
-            + day //
-            + 1749579;
-        break;
+        jd = 365 * year
+             + (year + 78 - 1 / month) / 4
+             + 31 * month
+             - (month + 9) / 11
+             - (month / 7) * (month - 7)
+             - (3 * ((year  + 78 - 1 / month) / 100 + 1)) / 4
+             + day
+             + 1749579;
     }
 
     case QCalendarSystem::IslamicCivilCalendar: {
         // Formula from the "Explanatory Supplement to the Astronomical Almanac"
         // Revised Edition 2006 section ??? pp ???, US Naval Observatory
         // Derived from Fliegel & Van Flandern 1968
-        jd = (3 + (11 * year)) / 30 //
-            + 354 * year //
-            + 30 * month //
-            - (month - 1) / 2 //
-            + day //
-            + epoch() //
-            - 385;
-        break;
+        jd = (3 + (11 * year)) / 30
+             + 354 * year
+             + 30 * month
+             - (month - 1) / 2
+             + day
+             + epoch()
+             - 385;
     }
 
     case QCalendarSystem::JulianCalendar: {
         // Formula from The Calendar FAQ by Claus Tondering
-        // https://www.tondering.dk/claus/calendar.html
+        // http://www.tondering.dk/claus/cal/node3.html#SECTION003161000000000000000
         int a = (14 - month) / 12;
         year = year + 4800 - a;
         int m = month + (12 * a) - 3;
-        jd = day //
-            + (((153 * m) + 2) / 5) //
-            + (365 * year) //
-            + (year / 4) //
-            - 32083;
+        jd = day
+             + (((153 * m) + 2) / 5)
+             + (365 * year)
+             + (year / 4)
+             - 32083;
         break;
     }
 
@@ -574,14 +581,16 @@ qint64 QCalendarSystemPrivate::julianDayFromDate(int year, int month, int day) c
 
 bool QCalendarSystemPrivate::isValidYear(int year) const
 {
-    return year >= earliestValidYear() //
-        && year <= latestValidYear() //
-        && (year == 0 ? hasYearZero() : true);
+    return year >= earliestValidYear() &&
+           year <= latestValidYear() &&
+           (year == 0 ? hasYearZero() : true);
 }
 
 bool QCalendarSystemPrivate::isValidMonth(int year, int month) const
 {
-    return isValidYear(year) && month >= 1 && month <= monthsInYear(year);
+    return isValidYear(year) &&
+           month >= 1 &&
+           month <= monthsInYear(year);
 }
 
 int QCalendarSystemPrivate::addYears(int y1, int years) const
@@ -668,17 +677,23 @@ int QCalendarSystem::maximumDaysInMonth() const
 
 bool QCalendarSystem::isValid(const QDate &date) const
 {
-    return date.isValid() && date >= earliestValidDate() && date <= latestValidDate();
+    return date.isValid() &&
+           date >= earliestValidDate() &&
+           date <= latestValidDate();
 }
 
 bool QCalendarSystem::isValid(int year, int month, int day) const
 {
-    return d->isValidMonth(year, month) && day >= 1 && day <= d->daysInMonth(year, month);
+    return d->isValidMonth(year, month) &&
+           day >= 1 &&
+           day <= d->daysInMonth(year, month);
 }
 
 bool QCalendarSystem::isValid(int year, int dayOfYear) const
 {
-    return d->isValidYear(year) && dayOfYear > 0 && dayOfYear <= d->daysInYear(year);
+    return d->isValidYear(year) &&
+           dayOfYear > 0 &&
+           dayOfYear <= d->daysInYear(year);
 }
 
 QDate QCalendarSystem::date(int year, int month, int day) const
@@ -725,7 +740,7 @@ int QCalendarSystem::year(const QDate &date) const
     int y = 0;
 
     if (isValid(date)) {
-        d->julianDayToDate(date.toJulianDay(), &y, nullptr, nullptr);
+        d->julianDayToDate(date.toJulianDay(), &y, 0, 0);
     }
 
     return y;
@@ -736,7 +751,7 @@ int QCalendarSystem::month(const QDate &date) const
     int m = 0;
 
     if (isValid(date)) {
-        d->julianDayToDate(date.toJulianDay(), nullptr, &m, nullptr);
+        d->julianDayToDate(date.toJulianDay(), 0, &m, 0);
     }
 
     return m;
@@ -747,7 +762,7 @@ int QCalendarSystem::day(const QDate &date) const
     int dd = 0;
 
     if (isValid(date)) {
-        d->julianDayToDate(date.toJulianDay(), nullptr, nullptr, &dd);
+        d->julianDayToDate(date.toJulianDay(), 0, 0, &dd);
     }
 
     return dd;
@@ -757,7 +772,7 @@ int QCalendarSystem::quarter(const QDate &date) const
 {
     if (isValid(date)) {
         int month;
-        d->julianDayToDate(date.toJulianDay(), nullptr, &month, nullptr);
+        d->julianDayToDate(date.toJulianDay(), 0, &month, 0);
         return d->quarter(month);
     } else {
         return 0;
@@ -789,7 +804,7 @@ int QCalendarSystem::dayOfYear(int year, int month, int day) const
 
 int QCalendarSystem::dayOfWeek(const QDate &date) const
 {
-    // jd 0 = Monday = weekday 1.  We've never skipped weekdays.
+    //jd 0 = Monday = weekday 1.  We've never skipped weekdays.
     if (isValid(date)) {
         if (date.toJulianDay() >= 0) {
             return (date.toJulianDay() % daysInWeek()) + 1;
@@ -806,13 +821,11 @@ int QCalendarSystem::dayOfWeek(int year, int month, int day) const
     return dayOfWeek(date(year, month, day));
 }
 
-// TODO These are ISO weeks, may need to localise
+//TODO These are ISO weeks, may need to localise
 int QCalendarSystem::weekNumber(const QDate &date, int *yearNum) const
 {
     if (isValid(date)) {
-        int year;
-        int month;
-        int day;
+        int year, month, day;
         d->julianDayToDate(date.toJulianDay(), &year, &month, &day);
         return weekNumber(year, month, day, yearNum);
     } else {
@@ -821,15 +834,24 @@ int QCalendarSystem::weekNumber(const QDate &date, int *yearNum) const
 }
 
 /*
-    The following method is based on code from tzcode's strftime.c, which is turn said to be
-    "Based on the UCB version with the ID appearing below."
+    \legalese
+    Copyright (c) 1989 The Regents of the University of California.
+    All rights reserved.
 
-    SPDX-FileCopyrightText: 1989 The Regents of the University of California. All rights reserved.
-
-    SPDX-License-Identifier: BSD-3-Clause
+    Redistribution and use in source and binary forms are permitted
+    provided that the above copyright notice and this paragraph are
+    duplicated in all such forms and that any documentation,
+    advertising materials, and other materials related to such
+    distribution and use acknowledge that the software was developed
+    by the University of California, Berkeley.  The name of the
+    University may not be used to endorse or promote products derived
+    from this software without specific prior written permission.
+    THIS SOFTWARE IS PROVIDED "AS IS" AND WITHOUT ANY EXPRESS OR
+    IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED
+    WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */
-// TODO These are ISO weeks, may need to localise
-// TODO Replace with cleanly licensed routine
+//TODO These are ISO weeks, may need to localise
+//TODO Replace with cleanly licensed routine
 int QCalendarSystem::weekNumber(int year, int month, int day, int *yearNum) const
 {
     if (!isValid(year, month, day)) {
@@ -847,9 +869,7 @@ int QCalendarSystem::weekNumber(int year, int month, int day, int *yearNum) cons
     int w;
 
     for (;;) {
-        int len;
-        int bot;
-        int top;
+        int len, bot, top;
 
         len = d->daysInYear(year);
         /*
@@ -913,7 +933,7 @@ int QCalendarSystem::weeksInYear(const QDate &date) const
     }
 }
 
-// TODO This is ISO weeks, may need to localise
+//TODO This is ISO weeks, may need to localise
 int QCalendarSystem::weeksInYear(int year) const
 {
     if (d->isValidYear(year)) {
@@ -949,9 +969,8 @@ int QCalendarSystem::daysInYear(int year) const
 int QCalendarSystem::daysInMonth(const QDate &date) const
 {
     if (isValid(date)) {
-        int year;
-        int month;
-        d->julianDayToDate(date.toJulianDay(), &year, &month, nullptr);
+        int year, month;
+        d->julianDayToDate(date.toJulianDay(), &year, &month, 0);
         return d->daysInMonth(year, month);
     } else {
         return 0;
@@ -993,9 +1012,7 @@ bool QCalendarSystem::isLeapYear(int year) const
 QDate QCalendarSystem::addYears(const QDate &dt, int years) const
 {
     if (isValid(dt)) {
-        int year;
-        int month;
-        int day;
+        int year, month, day;
         d->julianDayToDate(dt.toJulianDay(), &year, &month, &day);
         year = d->addYears(year, years);
         month = qMin(month, d->monthsInYear(year));
@@ -1008,16 +1025,14 @@ QDate QCalendarSystem::addYears(const QDate &dt, int years) const
 QDate QCalendarSystem::addMonths(const QDate &dt, int months) const
 {
     if (isValid(dt)) {
-        int year;
-        int month;
-        int day;
+        int year, month, day;
         d->julianDayToDate(dt.toJulianDay(), &year, &month, &day);
         while (months != 0) {
             if (months < 0) {
                 if (month + months >= 1) {
                     month += months;
                     months = 0;
-                } else {
+                } else if (months < 0) {
                     year = d->addYears(year, -1);
                     months += d->monthsInYear(year);
                 }
@@ -1043,7 +1058,7 @@ QDate QCalendarSystem::addDays(const QDate &date, int days) const
     return date.addDays(days);
 }
 
-// Caters for Leap Months, but possibly not for Hebrew
+//Caters for Leap Months, but possibly not for Hebrew
 int QCalendarSystem::yearsDifference(const QDate &fromDate, const QDate &toDate) const
 {
     if (!isValid(fromDate) || !isValid(toDate) || toDate == fromDate) {
@@ -1051,15 +1066,10 @@ int QCalendarSystem::yearsDifference(const QDate &fromDate, const QDate &toDate)
     }
 
     if (toDate < fromDate) {
-        return -yearsDifference(toDate, fromDate);
+        return - yearsDifference(toDate, fromDate);
     }
 
-    int y1;
-    int m1;
-    int d1;
-    int y2;
-    int m2;
-    int d2;
+    int y1, m1, d1, y2, m2, d2;
     d->julianDayToDate(fromDate.toJulianDay(), &y1, &m1, &d1);
     d->julianDayToDate(toDate.toJulianDay(), &y2, &m2, &d2);
 
@@ -1078,15 +1088,15 @@ int QCalendarSystem::yearsDifference(const QDate &fromDate, const QDate &toDate)
     // m2 == m1
     // Allow for last day of month to last day of month and leap days
     // e.g. 2000-02-29 to 2001-02-28 is 1 year not 0 years
-    if (d2 >= d1 //
-        || (d1 == d->daysInMonth(y1, m1) && d2 == d->daysInMonth(y2, m2))) {
+    if ((d2 >= d1) ||
+            (d1 == d->daysInMonth(y1, m1) && d2 == d->daysInMonth(y2, m2))) {
         return d->diffYears(y1, y2);
     } else {
         return d->diffYears(y1, y2) - 1;
     }
 }
 
-// Caters for Leap Months, but possibly not for Hebrew
+//Caters for Leap Months, but possibly not for Hebrew
 int QCalendarSystem::monthsDifference(const QDate &fromDate, const QDate &toDate) const
 {
     if (!isValid(fromDate) || !isValid(toDate) || toDate == fromDate) {
@@ -1094,16 +1104,10 @@ int QCalendarSystem::monthsDifference(const QDate &fromDate, const QDate &toDate
     }
 
     if (toDate < fromDate) {
-        return -monthsDifference(toDate, fromDate);
+        return - monthsDifference(toDate, fromDate);
     }
 
-    int y1;
-    int m1;
-    int d1;
-    int y2;
-    int m2;
-    int d2;
-    int my;
+    int y1, m1, d1, y2, m2, d2, my;
     d->julianDayToDate(fromDate.toJulianDay(), &y1, &m1, &d1);
     d->julianDayToDate(toDate.toJulianDay(), &y2, &m2, &d2);
 
@@ -1122,8 +1126,8 @@ int QCalendarSystem::monthsDifference(const QDate &fromDate, const QDate &toDate
     // Allow for last day of month to last day of month and leap days
     // e.g. 2010-03-31 to 2010-04-30 is 1 month not 0 months
     // also 2000-02-29 to 2001-02-28 is 12 months not 11 months
-    if (d2 >= d1 //
-        || (d1 == d->daysInMonth(y1, m1) && d2 == d->daysInMonth(y2, m2))) {
+    if ((d2 >= d1) ||
+            (d1 == d->daysInMonth(y1, m1) && d2 == d->daysInMonth(y2, m2))) {
         return my + m2 - m1;
     } else {
         return my + m2 - m1 - 1;
@@ -1139,8 +1143,9 @@ qint64 QCalendarSystem::daysDifference(const QDate &fromDate, const QDate &toDat
     }
 }
 
-// Caters for Leap Months, but possibly not for Hebrew
-void QCalendarSystem::dateDifference(const QDate &fromDate, const QDate &toDate, int *years, int *months, int *days, int *direction) const
+//Caters for Leap Months, but possibly not for Hebrew
+void QCalendarSystem::dateDifference(const QDate &fromDate, const QDate &toDate,
+                                     int *years, int *months, int *days, int *direction) const
 {
     int dy = 0;
     int dm = 0;
@@ -1149,15 +1154,10 @@ void QCalendarSystem::dateDifference(const QDate &fromDate, const QDate &toDate,
 
     if (isValid(fromDate) && isValid(toDate) && fromDate != toDate) {
         if (toDate < fromDate) {
-            dateDifference(toDate, fromDate, &dy, &dm, &dd, nullptr);
+            dateDifference(toDate, fromDate, &dy, &dm, &dd, 0);
             dir = -1;
         } else {
-            int y1;
-            int m1;
-            int d1;
-            int y2;
-            int m2;
-            int d2;
+            int y1, m1, d1, y2, m2, d2;
             d->julianDayToDate(fromDate.toJulianDay(), &y1, &m1, &d1);
             d->julianDayToDate(toDate.toJulianDay(), &y2, &m2, &d2);
 
@@ -1240,9 +1240,8 @@ QDate QCalendarSystem::lastDayOfYear(int year) const
 
 QDate QCalendarSystem::firstDayOfMonth(const QDate &dt) const
 {
-    int year;
-    int month;
-    getDate(dt, &year, &month, nullptr);
+    int year, month;
+    getDate(dt, &year, &month, 0);
     return date(year, month, 1);
 }
 
@@ -1253,9 +1252,8 @@ QDate QCalendarSystem::firstDayOfMonth(int year, int month) const
 
 QDate QCalendarSystem::lastDayOfMonth(const QDate &dt) const
 {
-    int year;
-    int month;
-    getDate(dt, &year, &month, nullptr);
+    int year, month;
+    getDate(dt, &year, &month, 0);
     return date(year, month, daysInMonth(year, month));
 }
 
